@@ -11,6 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
+import sys
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path.insert(0, os.path.abspath('../'))
+
 # -- General configuration ----------------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
@@ -18,6 +26,7 @@
 extensions = [
     'sphinx.ext.autodoc',
     'openstackdocstheme',
+    'ext.traits',
 ]
 
 # openstackdocstheme options
@@ -33,8 +42,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'os-traits'
-copyright = u'2016, OpenStack Foundation'
+project = 'os-traits'
+copyright = '2016-2020, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -58,6 +67,6 @@ html_theme = 'openstackdocs'
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
 latex_documents = [
-    ('index', 'doc-os-traits.tex', u'os-traits Documentation',
-     u'OpenStack Foundation', 'manual'),
+    ('index', 'doc-os-traits.tex', 'os-traits Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
